@@ -101,6 +101,8 @@ public:
     Config *config;
 
     bool writeSelectionFile(const QString &file, const QString &path) const;
+    void setWorkerLocale();
+    void setWorkerProxy();
 };
 
 bool BackendPrivate::writeSelectionFile(const QString &selectionDocument, const QString &path) const
@@ -116,6 +118,16 @@ bool BackendPrivate::writeSelectionFile(const QString &selectionDocument, const
     return true;
 }
 
+void BackendPrivate::setWorkerLocale()
+{
+    worker->setLocale(QLatin1String(setlocale(LC_MESSAGES, 0)));
+}
+
+void BackendPrivate::setWorkerProxy()
+{
+    worker->setProxy(QLatin1String(getenv("http_proxy")));
+}
+
 Backend::Backend()
         : d_ptr(new BackendPrivate)
 {
@@ -182,11 +194,7 @@ void Backend::reloadCache()
 
     int packageCount = depCache->Head().PackageCount;
     d->packagesIndex.resize(packageCount);
-
-    // Remove check when sid has >= 4.7
-    #if QT_VERSION >= 0x040700
     d->packages.reserve(packageCount);
-    #endif
 
     // Populate internal package cache
     int count = 0;
@@ -643,9 +651,7 @@ CacheState Backend::currentCacheState() const
 
     CacheState state;
     int pkgSize = d->packages.size();
-    #if QT_VERSION >= 0x040700
     state.reserve(pkgSize);
-    #endif
     for (int i = 0; i < pkgSize; ++i) {
         state.append(d->packages[i]->state());
     }
@@ -843,7 +849,8 @@ void Backend::commitChanges()
         }
     }
 
-    d->worker->setLocale(QLatin1String(setlocale(LC_MESSAGES, 0)));
+    d->setWorkerLocale();
+    d->setWorkerProxy();
     d->worker->commitChanges(packageList);
 }
 
@@ -878,7 +885,8 @@ void Backend::downloadArchives(const QString &listFile, const QString &destinati
     QDir dir(dirName);
     dir.mkdir(QLatin1String("packages"));
 
-    d->worker->setLocale(QLatin1String(setlocale(LC_MESSAGES, 0)));
+    d->setWorkerLocale();
+    d->setWorkerProxy();
     d->worker->downloadArchives(packages, destination);
 }
 
@@ -886,7 +894,8 @@ void Backend::installDebFile(const DebFile &debFile)
 {
     Q_D(Backend);
 
-    d->worker->setLocale(QLatin1String(setlocale(LC_MESSAGES, 0)));
+    d->setWorkerLocale();
+    d->setWorkerProxy();
     d->worker->installDebFile(debFile.filePath());
 }
 
@@ -901,7 +910,8 @@ void Backend::updateCache()
 {
     Q_D(Backend);
 
-    d->worker->setLocale(QLatin1String(setlocale(LC_MESSAGES, 0)));
+    d->setWorkerLocale();
+    d->setWorkerProxy();
     d->worker->updateCache();
 }
 
