@@ -31,6 +31,7 @@ class pkgSourceList;
 namespace QApt {
     class Cache;
     class Config;
+    class DebFile;
 }
 
 /**
@@ -457,6 +458,18 @@ Q_SIGNALS:
      */
     void commitProgress(const QString &status, int percentage);
 
+   /**
+    * Emitted during the install of a .deb file, giving the output
+    * of the dpkg process installing the .deb
+    *
+    * @param message A line of output from dpkg
+    *
+    * @since 1.2
+    *
+    * @see installDebFile(const DebFile &debFile)
+    */
+    void debInstallMessage(const QString &message);
+
    /**
     * Emits the progress of the Apt Xapian Indexer
     *
@@ -547,6 +560,18 @@ public Q_SLOTS:
      */
     void commitChanges();
 
+   /**
+    * Downloads the packages listed in the provided list file to the provided
+    * destination directory. The worker sends normal download event signals
+    * as usual, and this can be handled exactly like any other package download
+    *
+    * @param listFile The path to the package list file
+    * @param destination The path of the directory to download the packages to
+    */
+    void downloadArchives(const QString &listFile, const QString &destination);
+
+    void installDebFile(const DebFile &file);
+
     /**
      * A slot that Packages use to tell the backend they've changed.
      * (Used internally by QApt::Package. You likely will never use this)
@@ -634,6 +659,30 @@ public Q_SLOTS:
      */
     bool loadSelections(const QString &path);
 
+   /**
+    * Writes a list of packages that have been marked for installation. This
+    * list can then be loaded with the loadDownloadList() function to start
+    * downloading the packages.
+    *
+    * @param path The path to save the download list to
+    *
+    * @return @c true if savign succeeded, @c false if the saving failed
+    */
+    bool saveDownloadList(const QString &path) const;
+
+   /**
+    * Locks the package at either the current version if installed, or
+    * prevents automatic installation if not installed.
+    *
+    * The backend must be reloaded before the pinning will take effect
+    *
+    * @param package The package to control pinning for
+    * @param pin Whether to pin or unpin the package
+    *
+    * @return @c true on success, @c false on failure
+    */
+    bool setPackagePinned(QApt::Package *package, bool pin);
+
    /**
     * Tells the QApt Worker to initiate a rebuild of the Xapian package search
     * index.
@@ -648,6 +697,24 @@ public Q_SLOTS:
     */
     void updateXapianIndex();
 
+   /**
+    * Add the given .deb package archive to the APT package cache.
+    *
+    * To succeed, the .deb file's corresponding package must already be known
+    * to APT. The version of the package that the .deb file provides must match
+    * the candidate version from APT, and additionally the md5 sums of the .deb
+    * file and the candidate version of the package in APT must match.
+    *
+    * The main use for this function is to add .deb archives from e.g. a USB
+    * stick so that computers without internet connections can install/upgrade
+    * packages.
+    *
+    * @param archive The .deb archive to be added to the package cache
+    *
+    * @return @c true on success, @c false on failure
+    */
+    bool addArchiveToCache(const DebFile &archive);
+
 private Q_SLOTS:
     void serviceOwnerChanged(const QString &name, const QString &oldOwner, const QString &newOwner);
     void workerStarted();
